/******************************* spi.h *******************************/

#ifndef HEADER_SPI
#define HEADER_SPI

#include "constants.h"


// bit set in SPISR when transfer is complete
#define SPIF 0x80
// bit set in SPISR when SPI register is ready for new data
#define SPTEF 0x20		



// loops until data shifting is complete
#define SPI_WAIT_FOR_DATA while ( !(SPISR & SPIF) )
#define SPI_WAIT_FOR_SPACE while ( !(SPISR & SPTEF) )


// EEPROM chip select									 
#define SPI_CHIP_SELECT 0x08
#define ENABLE_SPI_TRANSFER PTM &= ~SPI_CHIP_SELECT
#define DISABLE_SPI_TRANSFER PTM |= SPI_CHIP_SELECT





#define SPI_LED_SELECT 0x02
#define LATCH_SPI_LED PTM |= SPI_LED_SELECT
#define UNLATCH_SPI_LED PTM &= ~SPI_LED_SELECT



// Port M
#define MASK_SPI_CLOCK 0x20
#define MASK_SPI_DATA 0x10
#define MASK_SPI_LATCH 0x01

// Port T
#define MASK_GS_LATCH 0x20
// 595 for audio channel selection
#define MASK_SHIFT_LATCH 0x10

// Port AD
#define AUDIO_INPUT_PIN 2
#define HUMAN_INPUT_PIN 3






// initializes SPI registers
void SPI_Init(void);


// sends a command byte
void IssueSPICommand(unsigned char command);


// momentarily set PTM3 high; for use in writing
void GlitchSPIChipSelect(void);


// outputs a buffer through SPI
// low end first
void SPI_OutBuffer(unsigned char *pBuf, unsigned int Length);



// sends 16bits of LED data out the SPI
void SPI_Out_16(unsigned short val);


// sends out a single clock pulse, independent of SPI transmission
// needed for grayscale LED driver
void SPI_Clock_Strobe(void);


// sends 4 bits of 0 out SPI
void SPI_Out_Nibble(void);   


// output bits for a grayscale LED driver
// outputs in reverse order so that input[0] cooresponds to Ch0
void SPI_GS_Out16(unsigned char *input);


// latches the grayscale registers
void SPI_GS_Latch(void);


// fills Audio with values of input bandpass channels 0 - (NumChan-1)
// sends a value through SPI to the 595 connected to the analog
// multiplexer, then reads the value on the proper port AD pin,
// specified by: AUDIO_INPUT_PIN  
// audio values are 10bit
void SPI_Retrieve_Audio(unsigned short *Audio, unsigned char NumChan);


// fills Buffer with values of human input pots and switches
// values are 10bit
void SPI_Retrieve_Human_Input(unsigned short *Buffer, unsigned char NumChan);



#endif
